"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const misc_utils_of_mine_generic_1 = require("misc-utils-of-mine-generic");
const canvasRender_1 = require("../browser/canvasRender");
const fileType = require("file-type");
/**
  Example of declaring a format codec that uses DOM canvas instance which must be provided by the user.
  
```ts
import  jimp from 'jimp'
class JimpProxy implements FormatProxyClass {
  async create() {
   return new JimpFormatCodec(Jimp)
  }
}
```
 */
class CanvasCodec {
    constructor() {
    }
    decode(buffer, format) {
        return __awaiter(this, void 0, void 0, function* () {
            let tt;
            const mime = format ? misc_utils_of_mine_generic_1.getMimeTypeForExtension(format) : (tt = fileType(buffer)) && tt.mime || undefined;
            if (!mime) {
                return;
            }
            const { canvas, height, width } = yield canvasRender_1.renderArrayBufferInCanvas(buffer, mime);
            var imgData = canvas.getContext('2d').getImageData(0, 0, width, height);
            return imgData;
        });
    }
    encode(data, format, quality) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const mat = cv.matFromImageData(data);
                const canvas = canvasRender_1.renderInCanvas(mat, { forceSameSize: true, rgba: true });
                mat.delete();
                return new Promise((resolve, reject) => {
                    canvas.toBlob(b => {
                        if (!b) {
                            return resolve(undefined);
                        }
                        const r = new FileReader();
                        r.onloadend = (a) => {
                            resolve(r.result || undefined);
                        };
                        r.onerror = r.onabort = () => {
                            r.error ? reject(r.error) : resolve(undefined);
                        };
                        r.readAsArrayBuffer(b);
                    }, misc_utils_of_mine_generic_1.getMimeTypeForExtension(format) || 'image/png', quality);
                });
            }
            catch (error) {
                console.error(error);
            }
        });
    }
}
exports.CanvasCodec = CanvasCodec;
//# sourceMappingURL=canvasCodec.js.map