"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const misc_utils_of_mine_generic_1 = require("misc-utils-of-mine-generic");
const file_1 = require("../file");
/**
 * Nor or opencv.js or this library implement any image format so users are
 * responsible of providing a FormatProxy using some library.
 *
 */
function installFormatProxy(proxy) {
    return __awaiter(this, void 0, void 0, function* () {
        proxies.push(proxy);
    });
}
exports.installFormatProxy = installFormatProxy;
function unInstallFormatProxies() {
    return __awaiter(this, void 0, void 0, function* () {
        proxies.length = 0;
    });
}
exports.unInstallFormatProxies = unInstallFormatProxies;
const proxies = [];
const codecs = [];
let _proxyLoaded = false;
function createCodec(proxy) {
    return __awaiter(this, void 0, void 0, function* () {
        return typeof proxy === 'function' ? yield proxy() : yield proxy.create();
    });
}
/**
 * @internal
 */
function loadFormatProxies() {
    return __awaiter(this, void 0, void 0, function* () {
        if (!_proxyLoaded) {
            _proxyLoaded = true;
            proxies.length && (yield misc_utils_of_mine_generic_1.serial(proxies.map(proxy => () => __awaiter(this, void 0, void 0, function* () {
                var p = yield createCodec(proxy);
                codecs.push(p);
            }))));
        }
    });
}
exports.loadFormatProxies = loadFormatProxies;
function unloadFormatProxies() {
    codecs.length = 0;
}
exports.unloadFormatProxies = unloadFormatProxies;
function getDefaultCodec() {
    var c = codecs.length ? codecs[0] : undefined;
    if (!c) {
        throw new Error('No codec found. you need to provide a proxy and wait for loadFormatProxies()');
    }
    return c;
}
exports.getDefaultCodec = getDefaultCodec;
function decodeOrThrow(buffer, format) {
    return __awaiter(this, void 0, void 0, function* () {
        const r = yield getDefaultCodec().decode(buffer, format);
        misc_utils_of_mine_generic_1.checkThrow(r, `Fail to decode buffer. ${format ? `requested format: ${format}` : ''}. Detected format: ${file_1.File.getBufferFileType(buffer) && file_1.File.getBufferFileType(buffer).mime || 'unknown'}`);
        return r;
    });
}
exports.decodeOrThrow = decodeOrThrow;
function encodeOrThrow(data, format, quality) {
    return __awaiter(this, void 0, void 0, function* () {
        const r = yield getDefaultCodec().encode(data, format, quality);
        misc_utils_of_mine_generic_1.checkThrow(r, 'Fail to encode to requested format ' + format + '. Given: ' + format);
        return r;
    });
}
exports.encodeOrThrow = encodeOrThrow;
//# sourceMappingURL=format.js.map