"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const misc_utils_of_mine_generic_1 = require("misc-utils-of-mine-generic");
/**
  Example of declaring a Jimp proxy as a class
  
```ts
import  jimp from 'jimp'
class JimpProxy implements FormatProxyClass {
  async create() {
   return new JimpFormatCodec(Jimp)
  }
}
```
 */
class JimpCodec {
    constructor(jimp) {
        this.jimp = jimp;
    }
    decode(buffer) {
        return __awaiter(this, void 0, void 0, function* () {
            const img = yield this.jimp.create(Buffer.from(buffer));
            return img.bitmap;
        });
    }
    encode(data, format, quality) {
        return __awaiter(this, void 0, void 0, function* () {
            const mime = misc_utils_of_mine_generic_1.getMimeTypeForExtension(format);
            if (!mime) {
                throw new Error('format not supported' + format);
            }
            var img = new this.jimp(Object.assign({}, data, { data: Buffer.from(data.data.buffer) }));
            const buffer = yield img.getBufferAsync(mime);
            return buffer;
        });
    }
}
exports.JimpCodec = JimpCodec;
//# sourceMappingURL=jimpCodec.js.map