"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const misc_utils_of_mine_generic_1 = require("misc-utils-of-mine-generic");
const format_1 = require("./format");
const misc_1 = require("./util/misc");
exports.FS_ROOT = '/work';
let FS_;
/**
 * gets the emscripten FS API
 */
function getFS() {
    return FS_;
}
exports.getFS = getFS;
/**
 * Loads opencv.js file. It will do it only once no matter if called multiple times.
 * In the browser a new script element is created to load the file while in Node.js
 * the file is loaded using a require() call.
 *
 * Returns a promise resolved when the library is ready or rejected if there's a problem.
 *
 * Notice that among the options users can define the location of opencv.js file, which
 * in the case of the browser it could be in an external server.
 */
function loadOpencv(options = {}) {
    if (options.force) {
        opencvLoaded = false;
        misc_utils_of_mine_generic_1.getGlobal().Module = undefined;
        FS_ = undefined;
    }
    if (opencvLoaded) {
        options.onloadCallback && options.onloadCallback();
        return Promise.resolve();
    }
    if (misc_utils_of_mine_generic_1.isNode()) {
        return loadOpencvNode(options);
    }
    else {
        return loadOpencvBrowser(options);
    }
}
exports.loadOpencv = loadOpencv;
let opencvLoaded = false;
function loadOpencvNode(o) {
    return new Promise(resolve => {
        const fileName = o.opencvJsExceptions ? 'opencv_exception.js' : 'opencv.js';
        const paths = [o.opencvJsLocation, `./node_modules/mirada/dist/src/${fileName}`, `./dist/src/${fileName}`].filter(misc_utils_of_mine_generic_1.notFalsy);
        const g = misc_utils_of_mine_generic_1.getGlobal();
        var path = paths.find(fs_1.existsSync);
        const resolved = path && misc_1.resolveNodeModule(path);
        if (!resolved) {
            throw misc_1.buildError(`${fileName} not found. in any of these: ${paths.join(', ')}`);
        }
        g.Module = {
            preRun: () => {
                if (typeof window !== 'object' && !g.Module.FS.analyzePath(exports.FS_ROOT).exists) {
                    g.Module.FS.mkdir(exports.FS_ROOT);
                    g.Module.FS.mount(g.Module.FS.filesystems.NODEFS, { root: o.cwd || process.cwd() || '.' }, exports.FS_ROOT);
                }
            },
            onRuntimeInitialized: () => __awaiter(this, void 0, void 0, function* () {
                yield finishSetup(o);
                o.onloadCallback && o.onloadCallback();
                resolve();
            }),
            onAbort: (e) => {
                console.error('Error has occurred in WebAssembly Module', e, e.stack);
                console.trace();
            }
        };
        try {
            // console.log(resolved)      
            g.cv = require(resolved);
        }
        catch (error) {
            console.error(`An error occurred when trying to load ${fileName} form ` + resolved, error, error.stack);
            throw error;
        }
    });
}
function finishSetup(o) {
    return __awaiter(this, void 0, void 0, function* () {
        opencvLoaded = true;
        yield misc_utils_of_mine_generic_1.serial((o.formatProxies || []).map(p => () => __awaiter(this, void 0, void 0, function* () {
            yield format_1.installFormatProxy(p);
        })));
        yield format_1.loadFormatProxies();
        FS_ = misc_utils_of_mine_generic_1.getGlobal().Module.FS;
    });
}
function loadOpencvBrowser(o) {
    return new Promise((resolve, reject) => {
        let script = document.createElement('script');
        script.setAttribute('async', '');
        script.setAttribute('type', 'text/javascript');
        script.addEventListener('load', () => __awaiter(this, void 0, void 0, function* () {
            const g = misc_utils_of_mine_generic_1.getGlobal();
            if (typeof g.cv !== 'undefined' && typeof g.cv.getBuildInformation !== 'undefined') {
                yield finishSetup(o);
                o.onloadCallback && o.onloadCallback();
                resolve();
            }
            else {
                g.cv = typeof g.cv === 'undefined' ? {} : g.cv;
                g.cv.onRuntimeInitialized = () => __awaiter(this, void 0, void 0, function* () {
                    yield finishSetup(o);
                    o.onloadCallback && o.onloadCallback();
                    resolve();
                });
            }
        }));
        const src = o.opencvJsLocation || (o.opencvJsExceptions ? 'opencv_exception.js' : 'opencv.js');
        script.addEventListener('error', () => {
            reject('Failed to load ' + src);
        });
        script.src = src;
        let node = document.getElementsByTagName('script')[0];
        node.parentNode.insertBefore(script, node);
    });
}
//# sourceMappingURL=opencvReady.js.map