"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const cross_fetch_1 = __importDefault(require("cross-fetch"));
const opencvReady_1 = require("../opencvReady");
/**
 * if given a file it ignores its contents and alwasys read again from FS
 */
function readFile(f, FS = cv.FS) {
    return FS.readFile(getFilePath(f));
}
exports.readFile = readFile;
/**
 * Returns file name / path of given file relative to emscripten FS root  (in the context of emscripten FS)
 */
function getFileName(path) {
    return path.startsWith(`${opencvReady_1.FS_ROOT}/`) ? path.substring(`${opencvReady_1.FS_ROOT}/`.length, path.length) : `${path}`;
}
exports.getFileName = getFileName;
/**
 * Returns absolute path of given file (in the context of emscripten FS)
 */
function getFilePath(path) {
    return path.startsWith(`${opencvReady_1.FS_ROOT}/`) ? path : `${opencvReady_1.FS_ROOT}/${path}`;
}
exports.getFilePath = getFilePath;
function writeFile(name, f, FS = cv.FS) {
    FS.writeFile(getFilePath(name), f);
}
exports.writeFile = writeFile;
function removeFile(f, FS = cv.FS) {
    FS.unlink(getFilePath(getFilePath(f)));
}
exports.removeFile = removeFile;
function isDir(f, FS = cv.FS) {
    try {
        return FS.isDir(FS.stat(getFilePath(f)).mode);
    }
    catch (error) {
        return false;
    }
}
exports.isDir = isDir;
function isFile(f, FS = cv.FS) {
    try {
        return FS.isFile(FS.stat(getFilePath(f)).mode);
    }
    catch (error) {
        return false;
    }
}
exports.isFile = isFile;
exports.fileUtil = {
    isDir, isFile, removeFile, writeFile, getFilePath, readFile, getFileName
};
function loadDataFile(url, name) {
    return __awaiter(this, void 0, void 0, function* () {
        name = name || url.substring(url.lastIndexOf('/') + 1, url.length);
        // Heads up! we need to verify that the files don't already exists if not it throws!
        if (!cv.FS.readdir('/').includes(name)) {
            const r = yield cross_fetch_1.default(url);
            yield cv.FS.createDataFile('/', name, new Uint8ClampedArray(yield r.arrayBuffer()), true, false, false);
        }
        return name;
    });
}
exports.loadDataFile = loadDataFile;
//# sourceMappingURL=fileUtil.js.map