import { File } from '../File';
import { Mat, Scalar } from '../types/opencv';
/**
 * Creates an CV ImageData object from given image.
 */
export declare function toImageData(img: Mat): {
    data: Uint8ClampedArray;
    width: any;
    height: any;
};
export declare const asImageData: typeof toImageData;
export declare function isMat(m: any): m is Mat;
/**
 * Returns a new image that is identical to given (1, 3 or 4 channels) but has 4 RGBA channels.
 */
export declare function toRgba(mat: Mat, dst?: Mat): Mat;
export declare function fromFile(f: string): Promise<Mat>;
export declare function fromArrayBuffer(a: ArrayBuffer): Promise<Mat>;
export declare function fromUrl(f: string): Promise<Mat>;
/**
 * Compare two images by getting the L2 error (square-root of sum of squared error). The lower the result the more similar are the images.
 */
export declare function compareL2(f1: Mat | File, f2: Mat | File, destroyBoth?: boolean): number;
export declare function asMat(f: File | Mat): Mat;
export declare function del(...m: Mat[]): void;
/**
 * sets the color of pixel at coords (x,y)
 */
export declare function set(m: Mat, x: number, y: number, val: Scalar): void;
/**
 * gets the color of pixel at coords (x,y)
 */
export declare function get(m: Mat, x: number, y: number): any[];
export declare function map(mat: Mat, dst: Mat, fn: (p: Scalar, x: number, y: number) => Scalar): void;
/**
 * for overload methods that won't accept undefined as argument, like 'mask' cv.add()
 */
export declare function noArray(): Mat;
